import pytest
from pytestqt.qtbot import QtBot
from PyQt6.QtWidgets import QApplication
import almasim.ui as ui
import sys
import faulthandler

faulthandler.enable()


@pytest.fixture(scope="session")
def app():
    """Fixture for setting up the QApplication instance."""
    app = QApplication(sys.argv)
    yield app
    app.quit()


@pytest.fixture
def main_window(qtbot: QtBot):
    """Fixture for setting up the main window."""
    window = ui.ALMASimulator()
    qtbot.addWidget(window)
    # window.show()
    yield window
    # window.close()


def test_ALMASimulator_creation(main_window):
    """Test the creation of the ALMASimulator window."""
    # Check if the main window is visible
    assert main_window


if __name__ == "__main__":
    pytest.main(["-v", __file__])



import os
import subprocess
import setuptools
from setuptools.command.install import install as _install


class InstallWithSubmodule(_install):
    def run(self):
        # Check if we are in a git repository
        if os.path.isdir(".git"):
            # Initialize and update submodule
            subprocess.check_call(
                ["git", "submodule", "update", "--init", "--recursive"]
            )

            # Install the submodule
            subprocess.check_call(["pip", "install", "./illustris_python"])
        else:
            print("Skipping submodule installation: not in a git repository")

        # Continue with the normal installation
        _install.run(self)


setuptools.setup(
    name="almasim",
    version="2.0",
    author="Michele Delli Veneri",
    author_email="micheledelliveneri@gmail.com",
    description="An ALMA Simulation package for a more civilized era.",
    long_description=open("README.rst").read(),
    long_description_content_type="text/x-rst",
    url="https://github.com/MicheleDelliVeneri/ALMASim",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.12.4",
    install_requires=[
        "astropy",
        "pyvo",
        "numpy",
        "pandas",
        "matplotlib",
        "seaborn",
        "pyQt6",
        "tqdm",
        "scipy",
        "h5py",
        "kaggle",
        "dask",
        "dask-expr",
        "dask_jobqueue",
        "distributed",
        "astromartini",
        "Hdecompose",
        "paramiko",
        "pysftp",
        "setuptools",
        "tenacity",
        "nifty8",
    ],
    cmdclass={
        "install": InstallWithSubmodule,
    },
)
